@@ -456,10 +456,16 @@ class RESTServer:
                         # DEBUG
                         if __debug__:
                             print(f"!EXCEPTION!: {e}")
+                            print(
+                                f"!INVALID DATA!: [{writer.get_extra_info('peername')[0]}] {request_data}"
+                            )
                         request_body = {}
 
                 # DEBUG
                 if __debug__:
+                    print(
+                        f"CLIENT DATA: [{writer.get_extra_info('peername')[0]}] {request_data}"
+                    )
                     print(
                         f"CLIENT BODY: [{writer.get_extra_info('peername')[0]}] {request_body}"
                     )
@@ -551,7 +557,7 @@ class RESTServer:
 
             await response.send(writer)
 
-            writer.write("\n")
+            writer.write("\n".encode())
 
             await writer.drain()
 
@@ -612,7 +618,7 @@ class RESTServer:
             print(f"SERVER: Started on {self.host}:{self.port}")
 
         self._server = await asyncio.start_server(
-            self.dispatch_noun, self.host, self.port, self.backlog
+            self.dispatch_noun, host=self.host, port=self.port, backlog=self.backlog
         )
 
     async def stop(self):
